@@ -325,5 +325,5 @@ class ReadonlyAdmin(admin.ModelAdmin):
 
     def __init__(self, model, admin_site):
         self.list_display = [field.name for field in model._meta.fields if field.name
-                             not in ['id', 'created', 'modified']]
+                             not in {'id', 'created', 'modified'}]
         super().__init__(model, admin_site)
